aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/core/NEON/kernels/NEPoolingLayerKernel.h
diff options
context:
space:
mode:
Diffstat (limited to 'arm_compute/core/NEON/kernels/NEPoolingLayerKernel.h')
-rw-r--r--arm_compute/core/NEON/kernels/NEPoolingLayerKernel.h17
1 files changed, 16 insertions, 1 deletions
diff --git a/arm_compute/core/NEON/kernels/NEPoolingLayerKernel.h b/arm_compute/core/NEON/kernels/NEPoolingLayerKernel.h
index bf06fdd639..a5de81137b 100644
--- a/arm_compute/core/NEON/kernels/NEPoolingLayerKernel.h
+++ b/arm_compute/core/NEON/kernels/NEPoolingLayerKernel.h
@@ -48,7 +48,7 @@ public:
~NEPoolingLayerKernel() = default;
/** Set the input and output tensors.
*
* @param[in] input Source tensor. Data types supported: QS8/F32.
* @param[out] output Destination tensor. Data types supported: Same as @p input.
* @param[in] pool_info Contains pooling operation information described in @ref PoolingLayerInfo.
*/
@@ -66,6 +66,14 @@ private:
*/
template <PoolingType pooling_type>
void pooling2_f32(const Window &window_input, const Window &window);
+ /** Function to perform 2x2 pooling for float16_t.
+ *
+ * @param[in] window_input Input region on which to execute the kernel.
+ * @param[in] window Output region on which to execute the kernel.
+ */
+ template <PoolingType pooling_type>
+ void pooling2_f16(const Window &window_input, const Window &window);
+
/** Function to perform 2x2 pooling for 8bit fixed point.
*
* @param[in] window_input Input region on which to execute the kernel.
@@ -80,6 +88,13 @@ private:
*/
template <PoolingType pooling_type>
void pooling3_f32(const Window &window_input, const Window &window);
+ /** Function to perform 3x3 pooling.
+ *
+ * @param[in] window_input Input region on which to execute the kernel.
+ * @param[in] window Output region on which to execute the kernel.
+ */
+ template <PoolingType pooling_type>
+ void pooling3_f16(const Window &window_input, const Window &window);
/** Function to perform 3x3 pooling for 8bit fixed point.
*
* @param[in] window_input Input region on which to execute the kernel.
@@ -48,7 +48,7 @@ public:
/** Set the input and output tensors.
*
- * @param[in] input Source tensor. Data types supported: QS8/F32.
+ * @param[in] input Source tensor. Data types supported: QS8/F16/F32.
* @param[out] output Destination tensor. Data types supported: Same as @p input.
* @param[in] pool_info Contains pooling operation information described in @ref PoolingLayerInfo.